@@ -3,7 +3,7 @@
 from pages.widgets_registry import get_widget
 from pages import settings
 from pages.models import Content
-from pages.widgets import ImageInput, VideoWidget, FileInput
+from pages.widgets import ImageInput, FileInput
 
 from django import forms
 from django.core.mail import send_mail
@@ -17,14 +17,18 @@ from django.utils.translation import ugettext_lazy as _
 from django.utils.safestring import mark_safe
 from django.utils.text import unescape_string_literal
 from django.template.loader import render_to_string
+from django.template import RequestContext
 
 import logging
 import os
 import time
 import re
+import six
+
+logging.basicConfig()
+logger = logging.getLogger("pages")
 
 PLACEHOLDER_ERROR = _("[Placeholder %(name)s had syntax error: %(error)s]")
-logger = logging.getLogger(__name__)
 
 
 def parse_placeholder(parser, token):
@@ -115,9 +119,8 @@ class PlaceholderNode(template.Node):
     def get_widget(self, page, language, fallback=Textarea):
         """Given the name of a placeholder return a `Widget` subclass
         like Textarea or TextInput."""
-        is_str = type(self.widget) == type(str())
-        is_unicode = type(self.widget) == type(unicode())
-        if is_str or is_unicode:
+        is_str = isinstance(self.widget, six.string_types)
+        if is_str:
             widget = get_widget(self.widget)
         else:
             widget = self.widget
@@ -133,7 +136,7 @@ class PlaceholderNode(template.Node):
         saved in the admin and passed to the placeholder save
         method."""
         result = {}
-        for key in data.keys():
+        for key in list(data.keys()):
             if key.startswith(self.name + '-'):
                 new_key = key.replace(self.name + '-', '')
                 result[new_key] = data[key]
@@ -224,7 +227,7 @@ class PlaceholderNode(template.Node):
             try:
                 t = template.Template(content, name=self.name)
                 content = mark_safe(t.render(context))
-            except TemplateSyntaxError, error:
+            except TemplateSyntaxError as error:
                 if global_settings.DEBUG:
                     content = PLACEHOLDER_ERROR % {
                         'name': self.name,
@@ -279,7 +282,7 @@ class ImagePlaceholderNode(PlaceholderNode):
         filename = ''
         if change and data:
             # the image URL is posted if not changed
-            if type(data) is unicode:
+            if type(data) is str:
                 return
 
             filename = get_filename(page, self, data)
@@ -318,7 +321,7 @@ class FilePlaceholderNode(PlaceholderNode):
         filename = ''
         if change and data:
             # the image URL is posted if not changed
-            if type(data) is unicode:
+            if type(data) is str:
                 return
 
             filename = get_filename(page, self, data)
@@ -363,34 +366,11 @@ class ContactPlaceholderNode(PlaceholderNode):
                     return _("An error as occured: your email has not been sent.")
         else:
             form = ContactForm()
-        renderer = render_to_string('pages/contact.html', {'form':form})
+        renderer = render_to_string('pages/contact.html', {'form':form}, 
+            RequestContext(request))
         return mark_safe(renderer)
 
 
-class VideoPlaceholderNode(PlaceholderNode):
-    """A youtube `PlaceholderNode`, just here as an example."""
-
-    widget = VideoWidget
-
-    def render(self, context):
-        content = self.get_content_from_context(context)
-        if not content:
-            return ''
-        if content:
-            video_url, w, h = content.split('\\')
-            m = re.search('youtube\.com\/watch\?v=([^&]+)', content)
-            if m:
-                video_url = 'http://www.youtube.com/v/' + m.group(1)
-            if not w:
-                w = 425
-            if not h:
-                h = 344
-            context = {'video_url': video_url, 'w': w, 'h': h}
-            renderer = render_to_string('pages/embed.html', context)
-            return mark_safe(renderer)
-        return ''
-
-
 class JsonPlaceholderNode(PlaceholderNode):
     """
     A `PlaceholderNode` that try to return a deserialized JSON object
@@ -403,5 +383,19 @@ class JsonPlaceholderNode(PlaceholderNode):
         try:
             return json.loads(str(content))
         except:
-            logger.error("Problem decoding json")
+            logger.warning("Problem decoding json")
         return content
+
+
+class MarkdownPlaceholderNode(PlaceholderNode):
+    """
+    A `PlaceholderNode` that return HTML from MarkDown format
+    """
+
+    widget = Textarea
+
+    def render(self, context):
+        """Render markdown."""
+        import markdown
+        content = self.get_content_from_context(context)
+        return markdown.markdown(content)
