@@ -1,7 +1,7 @@
 import authority
 
-from django.conf.urls.defaults import url, include, patterns
-from django.conf.urls.defaults import handler404, handler500
+from django.conf.urls import url, include, patterns
+from django.conf.urls import handler404, handler500
 from django.contrib import admin
 from django.conf import settings
 from pages.views import PageSitemap, MultiLanguagePageSitemap
