@@ -4,7 +4,7 @@ from pages.tests.test_functionnal import FunctionnalTestCase
 from pages.tests.test_unit import UnitTestCase
 from pages.tests.test_regression import RegressionTestCase
 #from pages.tests.test_pages_link import LinkTestCase
-from pages.tests.test_auto_render import AutoRenderTestCase
+#from pages.tests.test_auto_render import AutoRenderTestCase
 
 def suite():
     suite = unittest.TestSuite()
@@ -13,8 +13,13 @@ def suite():
         return suite
     suite.addTest(unittest.makeSuite(UnitTestCase))
     suite.addTest(unittest.makeSuite(RegressionTestCase))
+    try:
+        from pages.tests.test_selenium import SeleniumTestCase
+        suite.addTest(unittest.makeSuite(SeleniumTestCase))
+    except ImportError:
+        print("Install selenium and PhantomJS to run browsers tests")
     # suite.addTest(unittest.makeSuite(LinkTestCase))
-    suite.addTest(unittest.makeSuite(AutoRenderTestCase))
+    # suite.addTest(unittest.makeSuite(AutoRenderTestCase))
     # being the slower test I run it at the end
     suite.addTest(unittest.makeSuite(FunctionnalTestCase))
     return suite
