@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """Django page CMS test suite module"""
-from django.conf import settings
 from django.template import Template, RequestContext, Context
 from django.template import RequestContext, TemplateDoesNotExist
 from django.template import loader
@@ -17,7 +16,7 @@ class RegressionTestCase(TestCase):
         Test the issue 100
         http://code.google.com/p/django-page-cms/issues/detail?id=100
         """
-        setattr(settings, "PAGE_SHOW_START_DATE", True)
+        self.set_setting("PAGE_SHOW_START_DATE", True)
         c = self.get_admin_client()
         c.login(username= 'batiste', password='b')
         page_data = self.get_new_page_data()
@@ -29,8 +28,7 @@ class RegressionTestCase(TestCase):
         page1.status = Page.DRAFT
         page1.save()
 
-        page1.calculated_status
-        setattr(settings, "PAGE_SHOW_START_DATE", False)
+        self.assertEqual(page1.calculated_status, Page.DRAFT)
 
     def test_slug_bug(self):
         """
@@ -49,7 +47,7 @@ class RegressionTestCase(TestCase):
 
         try:
             response = c.get(self.get_page_url('toto/page1/'))
-        except TemplateDoesNotExist, e:
+        except TemplateDoesNotExist as e:
             if e.args != ('404.html',):
                 raise
 
@@ -179,7 +177,7 @@ class RegressionTestCase(TestCase):
     def test_urls_in_templates(self):
         """Test different ways of displaying urls in templates."""
         page = self.create_new_page()
-        from pages.http import get_request_mock
+        from pages.phttp import get_request_mock
         request = get_request_mock()
         temp = loader.get_template('pages/tests/test7.html')
         temp = loader.get_template('pages/tests/test6.html')
@@ -215,4 +213,37 @@ class RegressionTestCase(TestCase):
 
         pl1 = """{% load pages_tags %}{% pages_dynamic_tree_menu "wrong-slug" %}"""
         template = loader.get_template_from_string(pl1)
-        self.assertEqual(template.render(context), u'\n')
+        self.assertEqual(template.render(context), '\n')
+
+    def test_placeholder_bug(self):
+        """Test placeholder with django template inheritance works prepoerly.
+        http://code.google.com/p/django-page-cms/issues/detail?id=210
+        """
+        p1 = self.new_page(content={'slug':'test', 'one':'one', 'two': 'two'})
+        template = django.template.loader.get_template('pages/tests/extends.html')
+        context = Context({'current_page': p1, 'lang':'en-us'})
+        renderer = template.render(context)
+        self.assertTrue('one' in renderer)
+        self.assertTrue('two' in renderer)
+
+        from pages.utils import get_placeholders
+        self.assertEqual(
+            str(get_placeholders('pages/tests/extends.html')),
+            '[<Placeholder Node: one>, <Placeholder Node: two>]')
+
+    def test_param_position(self):
+        """There was a typo in the change_form.html"""
+        c = self.get_admin_client()
+        page = self.create_new_page(c)
+        response = c.get('/admin/pages/page/%d/?position=1' % page.id)
+        self.assertContains(response, "position=1", status_code=200)
+
+    def test_language_and_redirect(self):
+        """Language choice in the admin is not kept between redirects"""
+        c = self.get_admin_client()
+        page = self.create_new_page(c)
+        page_url = '/admin/pages/page/%d/?language=en' % page.id
+        page_data = self.get_new_page_data()
+        page_data['_continue'] = 'true'
+        response = c.post(page_url, page_data)
+        self.assertRedirects(response, page_url)
