@@ -4,9 +4,9 @@ from pages.models import Page, Content
 from pages.placeholders import PlaceholderNode, get_filename
 from pages.tests.testcase import TestCase, MockRequest
 from pages import urlconf_registry as reg
-from pages.http import get_language_from_request, get_slug
-from pages.http import get_request_mock, remove_slug
-from pages.utils import export_po_files, import_po_files, get_now
+from pages.phttp import get_language_from_request, get_slug
+from pages.phttp import get_request_mock, remove_slug
+from pages.utils import get_now
 from pages.views import details
 from pages.templatetags.pages_tags import get_page_from_string_or_id
 
@@ -115,9 +115,9 @@ class UnitTestCase(TestCase):
         context = Context({})
         pl1 = """{% load pages_tags %}{% get_page "get-page-slug" as toto %}{{ toto }}"""
         template = get_template_from_string(pl1)
-        self.assertEqual(template.render(context), u'None')
+        self.assertEqual(template.render(context), 'None')
         page = self.new_page({'slug': 'get-page-slug'})
-        self.assertEqual(template.render(context), u'get-page-slug')
+        self.assertEqual(template.render(context), 'get-page-slug')
 
     def test_placeholder_all_syntaxes(self):
         """Test placeholder syntaxes."""
@@ -186,7 +186,6 @@ class UnitTestCase(TestCase):
         template = get_template_from_string(pl1)
         self.assertEqual(template.render(context), 'some random value')
 
-
     def test_parsed_template(self):
         """Test the parsed template syntax."""
         setattr(settings, "DEBUG", True)
@@ -199,21 +198,7 @@ class UnitTestCase(TestCase):
         setattr(settings, "DEBUG", False)
         page = self.new_page({'title':'<b>{{ "hello"|wrong_filter }}</b>'})
         context = Context({'current_page': page, 'lang':'en-us'})
-        self.assertEqual(template.render(context), u'')
-
-
-    def test_video(self):
-        """Test video placeholder."""
-        page = self.new_page(content={
-            'title':'video-page',
-            'video':'http://www.youtube.com/watch?v=oHg5SJYRHA0\\\\'
-        })
-        context = Context({'current_page': page, 'lang':'en-us'})
-        pl1 = """{% load pages_tags %}{% videoplaceholder video %}"""
-        template = get_template_from_string(pl1)
-        self.assertNotEqual(template.render(context), '')
-        self.assertTrue(len(template.render(context)) > 10)
-
+        self.assertEqual(template.render(context), '')
 
     def test_placeholder_untranslated_content(self):
         """Test placeholder untranslated content."""
@@ -308,7 +293,7 @@ class UnitTestCase(TestCase):
         page_data = {'title': 'test', 'slug': 'test'}
         page = self.new_page(page_data)
 
-        context = RequestContext(MockRequest, {'page': page})
+        context = RequestContext(MockRequest(), {'page': page})
         template = Template('{% load pages_tags %}'
                             '{% get_content page "title" "en-us" as content %}'
                             '{{ content }}')
@@ -331,21 +316,21 @@ class UnitTestCase(TestCase):
         self.assertEqual(page.slug(language='en-us'), 'english')
 
         # default
-        context = RequestContext(MockRequest, {'page': page})
+        context = RequestContext(MockRequest(), {'page': page})
         template = Template('{% load pages_tags %}'
                             '{% get_content page "slug" as content %}'
                             '{{ content }}')
         self.assertEqual(template.render(context), 'english')
 
         # french specified
-        context = RequestContext(MockRequest, {'page': page, 'lang': 'fr'})
+        context = RequestContext(MockRequest(), {'page': page, 'lang': 'fr'})
         template = Template('{% load pages_tags %}'
                             '{% get_content page "slug" as content %}'
                             '{{ content }}')
         self.assertEqual(template.render(context), 'french')
 
         # english specified
-        context = RequestContext(MockRequest, {'page': page, 'lang': 'en-us'})
+        context = RequestContext(MockRequest(), {'page': page, 'lang': 'en-us'})
         template = Template('{% load pages_tags %}'
                             '{% get_content page "slug" as content %}'
                             '{{ content }}')
@@ -360,7 +345,7 @@ class UnitTestCase(TestCase):
         # cleanup the cache from previous tests
         page.invalidate()
 
-        context = RequestContext(MockRequest, {'page': page, 'lang':'en-us',
+        context = RequestContext(MockRequest(), {'page': page, 'lang':'en-us',
             'path':'/page-1/'})
         template = Template('{% load pages_tags %}'
                             '{% show_content page "title" "en-us" %}')
@@ -378,12 +363,29 @@ class UnitTestCase(TestCase):
         # cleanup the cache from previous tests
         page.invalidate()
 
-        context = RequestContext(MockRequest, {'page': page, 'lang':'en-us',
+        context = RequestContext(MockRequest(), {'page': page, 'lang':'en-us',
             'path':'/page-1/'})
         template = Template('{% load pages_tags %}'
                             '{% pages_siblings_menu page %}')
         renderer = template.render(context)
 
+    def test_admin_menu_tag(self):
+        """
+        Test the {% pages_admin_menu %} template tag with cookies.
+        """
+        page_data = {'title':'test', 'slug':'test'}
+        page = self.new_page(page_data)
+        # cleanup the cache from previous tests
+        page.invalidate()
+
+        request = MockRequest()
+        request.COOKIES['tree_expanded'] = "%d,10,20" % page.id
+        context = RequestContext(request, {'page': page, 'lang':'en-us',
+            'path':'/page-1/'})
+        template = Template('{% load pages_tags %}'
+                            '{% pages_admin_menu page %}')
+        renderer = template.render(context) 
+
     def test_show_absolute_url_with_language(self):
         """
         Test a {% show_absolute_url %} template tag  bug.
@@ -394,15 +396,15 @@ class UnitTestCase(TestCase):
         Content(page=page, language='fr-ch', type='slug', body='french').save()
 
         self.assertEqual(page.get_url_path(language='fr-ch'),
-            self.get_page_url(u'french'))
+            self.get_page_url('french'))
         self.assertEqual(page.get_url_path(language='en-us'),
-            self.get_page_url(u'english'))
+            self.get_page_url('english'))
 
-        context = RequestContext(MockRequest, {'page': page})
+        context = RequestContext(MockRequest(), {'page': page})
         template = Template('{% load pages_tags %}'
                             '{% show_absolute_url page "en-us" %}')
         self.assertEqual(template.render(context),
-            self.get_page_url(u'english'))
+            self.get_page_url('english'))
         template = Template('{% load pages_tags %}'
                             '{% show_absolute_url page "fr-ch" %}')
         self.assertEqual(template.render(context),
@@ -634,39 +636,6 @@ class UnitTestCase(TestCase):
 
         reg.registry = []
 
-    def test_po_file_imoprt_export(self):
-        """Test the po files export and import."""
-        try:
-            import polib
-        except ImportError:
-            raise unittest.SkipTest("Polib is not installed")
-
-        page1 = self.new_page(content={'slug':'page1', 'title':'english title'})
-        page1.save()
-        #Content(page=page1, language='en-us', type='title', body='toto').save()
-        Content(page=page1, language='fr-ch', type='title', body='french title').save()
-        page1.invalidate()
-
-        import StringIO
-        stdout = StringIO.StringIO()
-
-        # TODO: might be nice to use a temp dir for this test
-        export_po_files(path='potests', stdout=stdout)
-        self.assertTrue("Export language fr-ch" in stdout.getvalue())
-
-        f = open("potests/fr-ch.po", "r+")
-        old = f.read().replace('french title', 'translated')
-        f.seek(0)
-        f.write(old)
-        f.close()
-
-        stdout = StringIO.StringIO()
-        import_po_files(path='potests', stdout=stdout)
-
-        self.assertTrue("Update language fr-ch" in stdout.getvalue())
-        self.assertTrue(("Update page %d" % page1.id) in stdout.getvalue())
-        self.assertTrue(page1.title(language='fr-ch'), 'translated')
-
     def test_page_methods(self):
         """Test that some methods run properly."""
         page1 = self.new_page(content={'slug': 'page1', 'title':'hello'})
@@ -677,16 +646,16 @@ class UnitTestCase(TestCase):
         page2.save()
         self.assertEqual(
             page1.expose_content(),
-            u"hello"
+            "hello"
         )
         self.assertEqual(
              page2.slug_with_level(),
-            u"&nbsp;&nbsp;&nbsp;page2"
+            "&nbsp;&nbsp;&nbsp;page2"
         )
         p = Page(author=page1.author)
-        self.assertEqual(unicode(p), u"Page without id")
+        self.assertEqual(str(p), "Page without id")
         p.save()
-        self.assertEqual(unicode(p), u"Page %d" % p.id)
+        self.assertEqual(str(p), "Page %d" % p.id)
 
     def test_context_processor(self):
         """Test that the page's context processor is properly activated."""
@@ -700,13 +669,13 @@ class UnitTestCase(TestCase):
     def test_get_page_from_id_context_variable(self):
         """Test get_page_from_string_or_id with an id context variable."""
         page = self.new_page({'slug': 'test'})
-        self.assertEqual(get_page_from_string_or_id(unicode(page.id)), page)
+        self.assertEqual(get_page_from_string_or_id(str(page.id)), page)
 
         content = Content(page=page, language='en-us', type='test_id',
             body=page.id)
         content.save()
         context = Context({'current_page': page})
-        context = RequestContext(MockRequest, context)
+        context = RequestContext(MockRequest(), context)
         template = Template('{% load pages_tags %}'
                             '{% placeholder test_id as str %}'
                             '{% get_page str as p %}'
@@ -718,7 +687,7 @@ class UnitTestCase(TestCase):
         page = self.new_page({'slug': 'test'})
 
         context = Context({'current_page': page})
-        context = RequestContext(MockRequest, context)
+        context = RequestContext(MockRequest(), context)
         template = Template('{% load pages_tags %}'
                             '{% placeholder slug as str %}'
                             '{% get_page str as p %}'
@@ -736,7 +705,7 @@ class UnitTestCase(TestCase):
         pl1 = """{% load pages_tags %}{% get_page 1 as toto %}{{ toto }}"""
         template = get_template_from_string(pl1)
         page = self.new_page({'id': 1, 'slug': 'get-page-slug'})
-        self.assertEqual(template.render(context), u'get-page-slug')
+        self.assertEqual(template.render(context), 'get-page-slug')
 
     def test_get_page_template_tag_with_variable_containing_page_id(self):
         """Test get_page template tag with page argument given as a page id"""
@@ -747,7 +716,7 @@ class UnitTestCase(TestCase):
         page = self.new_page({'id': 1, 'slug': 'get-page-slug',
             'somepage': '1'})
         context = Context({'current_page': page})
-        self.assertEqual(template.render(context), u'get-page-slug')
+        self.assertEqual(template.render(context), 'get-page-slug')
 
     def test_get_page_template_tag_with_variable_containing_page_slug(self):
         """Test get_page template tag with page argument given as a page id"""
@@ -758,7 +727,7 @@ class UnitTestCase(TestCase):
         page = self.new_page({'slug': 'get-page-slug', 'somepage':
             'get-page-slug' })
         context = Context({'current_page': page})
-        self.assertEqual(template.render(context), u'get-page-slug')
+        self.assertEqual(template.render(context), 'get-page-slug')
 
     def test_variable_disapear_in_block(self):
         """Try to test the disapearance of a context variable in a block."""
@@ -772,7 +741,7 @@ class UnitTestCase(TestCase):
         template = get_template_from_string(tpl)
         page = self.new_page({'slug': 'get-page-slug'})
         context = Context({'current_page': page})
-        self.assertEqual(template.render(context), u'get-page-slug')
+        self.assertEqual(template.render(context), 'get-page-slug')
 
     def test_get_filename(self):
         placeholder = PlaceholderNode("placeholdername")
@@ -782,4 +751,52 @@ class UnitTestCase(TestCase):
         self.assertTrue("page_%d" % page.id in get_filename(page, placeholder, data))
         self.assertTrue(placeholder.name in get_filename(page, placeholder, data))
 
-
+    def test_json_placeholder(self):
+        tpl = ("{% load pages_tags %}{% jsonplaceholder p1 as v %}{{ v.a }}")
+        
+        template = get_template_from_string(tpl)
+        page = self.new_page({'p1': '{"a":1}'})
+        context = Context({'current_page': page})
+        self.assertEqual(template.render(context), '1')
+        
+        tpl = ("{% load pages_tags %}{% jsonplaceholder p1 %}")
+        template = get_template_from_string(tpl)
+        page = self.new_page({'p1': 'wrong'})
+        context = Context({'current_page': page})
+        self.assertEqual(template.render(context), 'wrong')
+        
+    def test_file_placeholder(self):
+        tpl = ("{% load pages_tags %}{% fileplaceholder f1 %}")
+        
+        template = get_template_from_string(tpl)
+        page = self.new_page({'f1': 'filename'})
+        context = Context({'current_page': page})
+        self.assertEqual(template.render(context), 'filename')
+        
+    def test_image_placeholder(self):
+        tpl = ("{% load pages_tags %}{% imageplaceholder f1 %}")
+        
+        template = get_template_from_string(tpl)
+        page = self.new_page({'f1': 'filename'})
+        context = Context({'current_page': page})
+        self.assertEqual(template.render(context), 'filename')
+        
+    def test_contact_placeholder(self):
+        tpl = ("{% load pages_tags %}{% contactplaceholder contact %}")
+        
+        template = get_template_from_string(tpl)
+        page = self.new_page({'contact': 'hello'})
+        context = Context({'current_page': page})
+        
+        import logging
+        logger = logging.getLogger("pages")
+        lvl = logger.getEffectiveLevel()
+        logger.setLevel(logging.ERROR)
+        
+        with self.assertRaises(ValueError): 
+            self.assertEqual(template.render(context), 'hello')
+            
+        logger.setLevel(lvl)
+            
+        context = Context({'current_page': page, 'request':get_request_mock()})
+        self.assertTrue("<form" in template.render(context))
