@@ -10,12 +10,16 @@ from django.template import TemplateDoesNotExist
 from django.contrib.sites.models import Site
 from django.utils.importlib import import_module
 from django.core.urlresolvers import clear_url_caches
+from six.moves import reload_module
 
 
 class MockRequest:
-    REQUEST = {'language': 'en'}
-    GET = {}
-    META = {}
+
+    def __init__(self):
+        self.REQUEST = {'language': 'en'}
+        self.GET = {}
+        self.META = {}
+        self.COOKIES = {}
 
 
 class Error404Expected(Exception):
@@ -47,7 +51,7 @@ class TestCase(TestCase):
 
     def tearDown(self):
         setattr(settings, 'ROOT_URLCONF', self.old_url_conf)
-        for name, value in self.settings_to_reset.items():
+        for name, value in list(self.settings_to_reset.items()):
             setattr(pages_settings, name, value)
         self.reset_urlconf()
         self.settings_to_reset = {}
@@ -88,8 +92,8 @@ class TestCase(TestCase):
                 reload(import_module(url_conf))
             except:
                 pass
-        reload(import_module('pages.urls'))
-        reload(import_module('pages.testproj.urls'))
+        reload_module(import_module('pages.urls'))
+        reload_module(import_module('pages.testproj.urls'))
         clear_url_caches()
 
 
@@ -113,7 +117,7 @@ class TestCase(TestCase):
             page.sites.add(Site.objects.get(id=1))
         # necessary to clear old URL cache
         page.invalidate()
-        for key, value in content.items():
+        for key, value in list(content.items()):
             Content(page=page, language='en-us', type=key, body=value).save()
         return page
 
